==> webkit-1.4.3.tar.gz: webkit-1.4.3/Source/WebKit2/WebProcess/WebPage/DrawingArea.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "DrawingArea.h"

// Subclasses
#include "ChunkedUpdateDrawingArea.h"

#if PLATFORM(MAC) || PLATFORM(WIN)
#include "DrawingAreaImpl.h"
#endif

#if ENABLE(TILED_BACKING_STORE)
#include "TiledDrawingArea.h"
#endif

#include "WebPageCreationParameters.h"

namespace WebKit {

PassOwnPtr<DrawingArea> DrawingArea::create(WebPage* webPage, const WebPageCreationParameters& parameters)
{
    switch (parameters.drawingAreaType) {
    case DrawingAreaTypeImpl:
#if PLATFORM(MAC) || PLATFORM(WIN)
        return DrawingAreaImpl::create(webPage, parameters);
#else
        return 0;
#endif
    case DrawingAreaTypeChunkedUpdate:
        return adoptPtr(new ChunkedUpdateDrawingArea(webPage));

#if ENABLE(TILED_BACKING_STORE)
    case DrawingAreaTypeTiled:
        return adoptPtr(new TiledDrawingArea(webPage));
#endif
    }

    return 0;
}

DrawingArea::DrawingArea(DrawingAreaType type, WebPage* webPage)
    : m_type(type)
    , m_webPage(webPage)
{
}

DrawingArea::~DrawingArea()
{
}

} // namespace WebKit

==> webkit-1.6.1.tar.gz: webkit-1.6.1/Source/WebKit2/WebProcess/WebPage/DrawingArea.cpp <==
/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "DrawingArea.h"

// Subclasses
#include "DrawingAreaImpl.h"

#if ENABLE(TILED_BACKING_STORE)
#include "TiledDrawingArea.h"
#endif

#include "WebPageCreationParameters.h"

namespace WebKit {

PassOwnPtr<DrawingArea> DrawingArea::create(WebPage* webPage, const WebPageCreationParameters& parameters)
{
    switch (parameters.drawingAreaType) {
    case DrawingAreaTypeImpl:
        return DrawingAreaImpl::create(webPage, parameters);
#if ENABLE(TILED_BACKING_STORE)
    case DrawingAreaTypeTiled:
        return adoptPtr(new TiledDrawingArea(webPage));
#endif
    }

    return nullptr;
}

DrawingArea::DrawingArea(DrawingAreaType type, WebPage* webPage)
    : m_type(type)
    , m_webPage(webPage)
{
}

DrawingArea::~DrawingArea()
{
}

} // namespace WebKit
